@@ -4,8 +4,8 @@ y obtener resumen de sus caracteristicas.
 '''
 
 from cProfile import label
-import individual
-from functions import fitness,outer_product
+from .individual import Individual
+from .functions import fitness,outer_product
 
 import random
 import itertools
@@ -118,7 +118,7 @@ class Population:
             that as a generation 0 population. Defaults to 0.
         '''
         if not pop:     
-            self.indiv = [individual.Individual(i,
+            self.indiv = [Individual(i,
                                     self.name,
                                     self.size,
                                     self.ploidy,
@@ -459,7 +459,7 @@ class Population:
 
         Ind_Name = x
         # genera un nuevo individuo y lo devuelve al metodo evolvePop
-        return individual.Individual(Ind_Name,
+        return Individual(Ind_Name,
                          self.name,
                          self.size,
                          self.ploidy,
